@@ -1,4 +1,3 @@
-context("misc tests")
 
 test_all <- identical (Sys.getenv ("MPADGE_LOCAL"), "true")
 
@@ -22,8 +21,8 @@ test_that ("sequential structure", {
                               "Sequential distances calculated along values")
 })
 
-havdist <- function (x, y)
-{
+havdist <- function (x, y) {
+
     if (missing (y))
         y <- x
     x1mat <- array (x [, 1], dim = c (nrow (x), nrow (y)))
@@ -37,7 +36,7 @@ havdist <- function (x, y)
     earth <- 6378137 # radius of Earth in m
     d <- syd * syd +
         cos (x2mat * pi / 180) * cos (y2mat * pi / 180) * sxd * sxd
-    2 * earth * asin (sqrt (d));
+    2 * earth * asin (sqrt (d))
 }
 
 test_that("matrix structure for x only", {
@@ -93,12 +92,18 @@ test_that("geodesic extreme cases", {
 
 test_that ("geodist_benchmark", {
                d <- geodist_benchmark (lat = 1, d = 100, n = 100)
-               expect_is (d, "matrix")
+               expect_true (inherits (d, "matrix"))
                expect_equal (nrow (d), 2)
                expect_equal (ncol (d), 3)
                expect_equal (rownames (d), c ("absolute", "relative"))
                expect_equal (colnames (d),
                              c ("haversine", "vincenty", "cheap"))
+
+               # benchmarking is restricted to 2 <= n <= 1e3
+               expect_error (geodist_benchmark (n = 1),
+                     "Comparisons require at least n = 2 objects")
+               expect_error (geodist_benchmark (n = 1e3 + 1),
+                     "nothing to be gained by extending beyond a million")
 })
 
 test_that ("geodist paired", {
@@ -115,7 +120,7 @@ test_that ("geodist paired", {
                               "Maximum distance is > 100km")
               else
                   d1 <- geodist (x, y, paired = TRUE)
-              expect_is (d1, "numeric")
+              expect_type (d1, "double")
               expect_equal (length (d1), n)
 
               expect_silent (d2 <- geodist (x, y, paired = TRUE,
@@ -150,10 +155,11 @@ test_that ("geodist_vec", {
                              "x1 and y1 must have the same length")
 
                measures <- c ("cheap", "haversine", "vincenty", "geodesic")
-               for (m in measures)
-               {
+               for (m in measures) {
+
                    d1 <- geodist (x, y, paired = TRUE, measure = m)
-                   d2 <- geodist_vec (x1, y1, x2, y2, paired = TRUE, measure = m)
+                   d2 <- geodist_vec (x1, y1, x2, y2,
+                                      paired = TRUE, measure = m)
                    expect_identical (d1, d2)
 
                    d1 <- geodist (x, sequential = TRUE, measure = m)
@@ -169,3 +175,22 @@ test_that ("geodist_vec", {
                    expect_identical (d1, d2)
                }
 })
+
+test_that ("argument quiet for measure cheap works", {
+    x1 <- c(0, 1)
+    y1 <- c(0, 1)
+    x2 <- c(2, 3)
+    y2 <- c(2, 3)
+    x <- cbind ("x" = x1, "y" = y1)
+    y <- cbind ("x" = x2, "y" = y2)
+
+    expect_message (d1 <- geodist (x, y, paired = TRUE),
+                    "Maximum distance is > 100km")
+    expect_silent (d1 <- geodist (x, y, paired = TRUE, quiet = TRUE))
+
+    expect_message (d1 <- geodist_vec (x1, y1, x2, y2, paired = TRUE),
+                    "Maximum distance is > 100km")
+    expect_silent (d1 <- geodist_vec (x1, y1, x2, y2,
+                                      paired = TRUE, quiet = TRUE))
+
+})
